@@ -56,7 +56,7 @@ sub new
 		,'lin',0,'',
 			'shortcut for enforcing linear interpolation'
 		,'spline',0,'',
-			'shortcut for enforcing spline interpolation (overrules --line)'
+			'shortcut for enforcing spline interpolation (overrules --lin)'
 		,'headcode','','C',
 			'FullFun: Some code that gets eval()ed with possibility to parse/modify every head line (variable $line; line number is $num).'
 		,'aftercode','','A',
